CODEOFCONDUCT = \
'''
Python Community Code of Conduct

The Python community is made up of members from around the globe with a diverse set of skills, personalities, and experiences. It is through these differences that our community experiences great successes and continued growth. When you're working with members of the community, we encourage you to follow these guidelines which help steer our interactions and strive to keep Python a positive, successful, and growing community.

A member of the Python community is:
Open

Members of the community are open to collaboration, whether it's on PEPs, patches, problems, or otherwise. We're receptive to constructive comment and criticism, as the experiences and skill sets of other members contribute to the whole of our efforts. We're accepting of all who wish to take part in our activities, fostering an environment where anyone can participate and everyone can make a difference.
Considerate

Members of the community are considerate of their peers -- other Python users. We're thoughtful when addressing the efforts of others, keeping in mind that often times the labor was completed simply for the good of the community. We're attentive in our communications, whether in person or online, and we're tactful when approaching differing views.
Respectful

Members of the community are respectful. We're respectful of others, their positions, their skills, their commitments, and their efforts. We're respectful of the volunteer efforts that permeate the Python community. We're respectful of the processes set forth in the community, and we work within them. When we disagree, we are courteous in raising our issues.

Overall, we're good to each other. We contribute to this community not because we have to, but because we want to. If we remember that, these guidelines will come naturally.
'''

def display():
    print CODEOFCONDUCT


import json
import urllib2

BASE_URL  = 'https://api.meetup.com'
GROUP_URL = 'PyMNtos-Twin-Cities-Python-User-Group'
GROUP_ID  = 9892262

class Meetup(object):
    def __init__(self, api_key):
        self.api_key = api_key

    def request(self, path):
        url = '{0}/{1}/?key={2}'.format(BASE_URL, path, self.api_key)
        resp = urllib2.urlopen(url)
        return json.loads(resp.read())

    def group_info(self):
        return self.request(GROUP_URL)

    def next_meeting(self):
        group = self.group_info()
        event_id = group['next_event']['id']
        return self.request('2/event/' + event_id)


from setuptools import setup

setup(name='pymntos',
      version='0.2',
      description='PyMNtos library',
      url='http://bitbucket.org/wyattwalter/pymntos-lib',
      author='Wyatt Walter',
      author_email='wyattwalter@gmail.com',
      license='MIT',
      packages=['pymntos'],
      install_requires=[
          'docopt',
      ],
      scripts=['bin/pymntos'])
